@@ -1,12 +1,13 @@
 var results = {
 
 "Acme-CPANAuthors-French-0.07": [
-  {status:"FAIL",id:"2967432",perl:"5.10.0",osname:"linux",ostext:"Linux",osvers:"2.6.24-1-amd64",archname:"x86_64-linux",perlmat:"rel"},
-  {status:"FAIL",id:"2966560",perl:"5.8.8",osname:"linux",ostext:"Linux",osvers:"2.6.18-92.1.18.el5",archname:"s390x-linux-thread-multi",perlmat:"rel"}
+  {status:"FAIL",id:"2967432",perl:"5.10.0",osname:"linux",ostext:"LINUX",osvers:"2.6.24-1-amd64",archname:"x86_64-linux",perlmat:"rel"},
+  {status:"FAIL",id:"2966560",perl:"5.8.8",osname:"linux",ostext:"LINUX",osvers:"2.6.18-92.1.18.el5",archname:"s390x-linux-thread-multi",perlmat:"rel"},
+  {status:"FAIL",id:"2549071",perl:"5.8.8",osname:"openbsd",ostext:"OPENBSD",osvers:"4.2",archname:"OpenBSD.i386-openbsd-thread-multi-64int",perlmat:"rel"}
 ],
 
 "Acme-CPANAuthors-French-0.06": [
-
+  {status:"FAIL",id:"2538246",perl:"5.8.8",osname:"freebsd",ostext:"FREEBSD",osvers:"6.2-release",archname:"i386-freebsd-thread-multi-64int",perlmat:"rel"}
 ],
 
 "Acme-CPANAuthors-French-0.05": [
