@@ -1,7 +1,7 @@
 var results = {
 
 "Acme-CPANAuthors-Japanese-0.090101": [
-  {status:"PASS",id:"2975969",perl:"5.10.0",osname:"MSWin32",ostext:"MSWin32",osvers:"5.1",archname:"MSWin32-x86-multi-thread",perlmat:"rel"}
+  {status:"PASS",id:"2975969",perl:"5.10.0",osname:"mswin32",ostext:"MSWin32",osvers:"5.1",archname:"MSWin32-x86-multi-thread",perlmat:"rel"}
 ],
 
 "Acme-CPANAuthors-Japanese-0.080522": [
